#!/bin/bash 

module add samtools
module add tabix

echo "The following scripts performs post imputation quality filtering"
echo "WARNING: filter below is MAF >= 0.05% & estimated R2 > 0.8. If not desired, please change by searching the two instances containing '0.0005' below"
echo ""

starttime=`date`
echo "starting @ $starttime"
echo ""

vcf=imp_out.vcf.gz
# make sure this vcf file is bgzipped; otherwise, unzip first and then apply:
# bgzip -f my.vcf
info=imp_out.info
outdir=./filtered
mkdir -p $outdir

tabix -f -pvcf $vcf
bcftools view -Oz -i 'INFO/MAF>=0.0005 & INFO/R2>0.8' $vcf -o $outdir/imp_out_estR2_0.8.vcf.gz
tabix -f -pvcf $outdir/imp_out_estR2_0.8.vcf.gz

awk '$5 >= 0.0005 && $7 > 0.8' $info > $outdir/imp_out_estR2_0.8.info

# sanity checks
infom=`sed 1,1d $outdir/imp_out_estR2_0.8.info | wc -l`
vcfm=`zcat $outdir/imp_out_estR2_0.8.vcf.gz | grep -v "^#" | wc -l`
# expect two wc identical
echo ""
if [ $infom -ne $vcfm ] ; then
  echo "ERROR: #markers do not match. info file contains $infom markers and vcf file contains $vcfm markers"
else
  echo "GREAT: #markers match = $infom"
fi

echo "post imputation filtering successfully completed" 
endtime=`date`
echo "ended at $endtime"
echo ""




